@@ -1,4 +1,4 @@
-from .misc import peek, clear_screen, copy_to_clipboard, make_iter, expand_path
+from .misc import peek, clear_screen, copy_to_clipboard, make_iter, expand_path, render_code_display
 from .printer import printer
 from .loader import Loader
 from .editor import open_in_editor
